#[non_exhaustive]pub enum PreparedNavmeshBuildError {
InvalidNavmesh {
source: NavmeshValidationError,
},
}Expand description
Prepared navmesh preprocess failed because the source mesh failed validation.
Fail-closed: builders do not emit a partial prepared map when validation fails.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Source Navmesh failed Navmesh::validate during preprocess.