pub struct AnyAnglePath { /* private fields */ }Expand description
Non-empty polyline in grid coordinates with Euclidean traversal cost.
Implementations
Sourceimpl AnyAnglePath
impl AnyAnglePath
Sourcepub fn from_points(
points: Vec<Point2>,
) -> Result<AnyAnglePath, AnyAnglePathBuildError>
pub fn from_points( points: Vec<Point2>, ) -> Result<AnyAnglePath, AnyAnglePathBuildError>
Builds a path and sets cost to the sum of consecutive Euclidean segments.
Errors
Returns AnyAnglePathBuildError::Empty when points is empty.
Sourcepub fn from_points_with_cost(
points: Vec<Point2>,
cost: f64,
) -> Result<AnyAnglePath, AnyAnglePathBuildError>
pub fn from_points_with_cost( points: Vec<Point2>, cost: f64, ) -> Result<AnyAnglePath, AnyAnglePathBuildError>
Builds a path with an explicit cost (callers must ensure consistency with geometry).
Errors
Returns AnyAnglePathBuildError::Empty when points is empty.
Sourcepub fn points(&self) -> &[Point2]
pub fn points(&self) -> &[Point2]
Ordered continuous vertices from start through goal (inclusive).
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Always false for successfully constructed paths (from_points* reject empty).